==> pgz-spaceinvaders_0.3.1.tar.gz: pgz-spaceinvaders-0.3.1/qml/pgz-spaceinvaders/storage.js <==
//storage.js
//Possible Settings:
var FlashOnFire = "TRUE";
var UseAccelerometer = "TRUE";
var SFX = "TRUE";
var GamerName = "";
var Password = "";

var Pos1Level = 0;
var Pos1Score = 0;
var Pos1Date = "";

var Pos2Level = 0;
var Pos2Score = 0;
var Pos2Date = "";

var Pos3Level = 0;
var Pos3Score = 0;
var Pos3Date = "";

var Pos4Level = 0;
var Pos4Score = 0;
var Pos4Date = "";

var Pos5Level = 0;
var Pos5Score = 0;
var Pos5Date = "";

var Pos6Level = 0;
var Pos6Score = 0;
var Pos6Date = "";



// First, let's create a short helper function to get the database connection
function getDatabase() {
     return openDatabaseSync("pgz-spaceinvaders-v2", "1.0", "StorageDatabase", 100000);
}

// At the start of the application, we can initialize the tables we need if they haven't been created yet
function initialize() {
    var db = getDatabase();
    db.transaction(
        function(tx) {
            // Create the settings table if it doesn't already exist
            // If the table exists, this is skipped
            tx.executeSql('CREATE TABLE IF NOT EXISTS settings(setting TEXT UNIQUE, value TEXT)');
          });
}

// This function is used to write a setting into the database
function setSetting(setting, value) {
   // setting: string representing the setting name (eg: “username”)
   // value: string representing the value of the setting (eg: “myUsername”)
   var db = getDatabase();
   var res = "";
   db.transaction(function(tx) {
        var rs = tx.executeSql('INSERT OR REPLACE INTO settings VALUES (?,?);', [setting,value]);
              //console.log(rs.rowsAffected)
              if (rs.rowsAffected > 0) {
                res = "OK";
              } else {
                res = "Error";
              }
        }
  );
  // The function returns “OK” if it was successful, or “Error” if it wasn't
  return res;
}
// This function is used to retrieve a setting from the database
function getSetting(setting) {
   var db = getDatabase();
   var res="";
   db.transaction(function(tx) {
     var rs = tx.executeSql('SELECT value FROM settings WHERE setting=?;', [setting]);
     if (rs.rows.length > 0) {
          res = rs.rows.item(0).value;
     } else {
         res = "Unknown";
     }
  })
  // The function returns “Unknown” if the setting was not found in the database
  // For more advanced projects, this should probably be handled through error codes
  return res
}

==> pgz-spaceinvaders_0.3.4.tar.gz: pgz-spaceinvaders-0.3.4/qml/pgz-spaceinvaders/storage.js <==
//storage.js

// First, let's create a short helper function to get the database connection
function getDatabase() {
     return openDatabaseSync("pgz-spaceinvaders-v2", "1.0", "StorageDatabase", 100000);
}

// At the start of the application, we can initialize the tables we need if they haven't been created yet
function initialize() {
    var db = getDatabase();
    db.transaction(
        function(tx) {
            // Create the settings table if it doesn't already exist
            // If the table exists, this is skipped
            tx.executeSql('CREATE TABLE IF NOT EXISTS settings(setting TEXT UNIQUE, value TEXT)');
          });
}

// This function is used to write a setting into the database
function setSetting(setting, value) {
   // setting: string representing the setting name (eg: “username”)
   // value: string representing the value of the setting (eg: “myUsername”)
   var db = getDatabase();
   var res = "";
   db.transaction(function(tx) {
        var rs = tx.executeSql('INSERT OR REPLACE INTO settings VALUES (?,?);', [setting,value]);
              //console.log(rs.rowsAffected)
              if (rs.rowsAffected > 0) {
                res = "OK";
              } else {
                res = "Error";
              }
        }
  );
  // The function returns “OK” if it was successful, or “Error” if it wasn't
  return res;
}
// This function is used to retrieve a setting from the database
function getSetting(setting, defaultvalue) {
   var db = getDatabase();
   var res="";
   db.transaction(function(tx) {
     var rs = tx.executeSql('SELECT value FROM settings WHERE setting=?;', [setting]);
     if (rs.rows.length > 0) {
          res = rs.rows.item(0).value;
     } else {
         res = defaultvalue;
     }
  })
  // The function returns “Unknown” if the setting was not found in the database
  // For more advanced projects, this should probably be handled through error codes
  return res
}
